from odoo import models, fields, api
from odoo.exceptions import UserError

class LoempiaPurchaseWizard(models.TransientModel):
    _name = "loempia.purchase.wizard"
    _description = "Purchase creation wizard test"

    def _get_module(self):
        return self.env['loempia.module'].browse(self.env.context['active_id']).id

    def _get_user(self):
        return self.env.user.id

    module_id = fields.Many2one('loempia.module', string="Module", readonly=True, default=_get_module)
    quantity = fields.Float('Quantity', required=True, default=1)
    user_id = fields.Many2one('res.users', required=True, default=_get_user)
    state = fields.Selection([
        ('draft', 'In Cart'),
        ('confirmed', 'Confirmed'),
        ('done', 'Done'),
        ('cancel', 'Cancelled'),
        ('exception', 'Exception'),
        ('redeemed', 'Redeemed'),
    ], string='Status', required=True, default='draft')

    @api.multi
    def confirm(self):
        self.ensure_one()
        module_id = self.module_id._get_commercial_series_module_id()
        purchase_number = self.env['loempia.module.purchase'].search_count([]) + 1
        if module_id.product_id:
            values = {
                'order_id': purchase_number,
                'order_name': "SOTEST/00000%s" % str(purchase_number),
                'quantity': self.quantity,
                'user_id': self.user_id.id,
                'module_id': module_id.id,
                'template_id': module_id.template_id.id,
                'product_id': module_id.product_id,
                'price_unit': module_id.price_single,
                'date_order': fields.date.today(),
                'state': self.state
            }
            self.env['loempia.module.purchase'].create(values)
            return {'type': 'ir.actions.act_window_close'}
        else:
            raise UserError("Please use a module with an associated product_id to create a test confirmed purchase")
